##  Overview
The SAP LeanIX GraphQL API employs the concept of [relay cursor connections![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Frelay.dev%2Fgraphql%2Fconnections.htm "https://relay.dev/graphql/connections.htm") for pagination, allowing for efficient and flexible data retrieval. In this pagination model, instead of using offsets, the API uses cursors to navigate through the dataset. Cursor-based pagination allows for immediate access to specific items within large datasets, unlike offset-based pagination, which can be inefficient for high offset values.
This pagination method provides real-time data, reflecting the current state of the dataset. Paginated requests don't create static snapshots of data. Instead, data is delivered dynamically. Due to the real-time nature of the data, idempotence is not guaranteed in paginated requests. This means that the same request with the same query parameters may return different results if the underlying data has changed between requests, ensuring you always receive the most up-to-date information.
For additional information on pagination in GraphQL, refer to the [GraphQL documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgraphql.org%2Flearn%2Fpagination%2F "https://graphql.org/learn/pagination/").
